{$i-,f+}
{$m $ff02,0,65535}

program TESTCORE (input, output);

uses
  graph, crt, CORE, CORE2, CORE3, CORE5, CYPHER;

var
  GraphicsDriver, GraphicsMode : integer;
  TEKST                        : string;

begin
  SETPAL (LIGHTGRAY, 255,0,0);
(*  writeln (GETFILESIZE ('VADER.RAW'));*)
  writeln (Anything('chr$(92)+right$("Hello world", 5)'));
  readln;
  GraphicsDriver:= vga;
  GraphicsMode:= vgahi;
  initgraph (GraphicsDriver, GraphicsMode, 'c:\tp\bgi');
  textcolor (YELLOW);
  textbackground (RED);
  PRINTVGA (0,0, 'Hello world.');
  gotoxy (length('Hello world.')+1,1);
  SHOWIMAGEVGA ('vader.RAW');
  READLNVGA (TEKST);

  closegraph;
  MCGAINIT;
  directvideo:= false;
  Textcolor (BLUE);
  TextBackground (MAGENTA);
  PRINTMCGA ('Hello world.');
  LINEMCGA (0,0,319,199);
(*  write (GETFILESIZE ('VADER.RAW'));*)
  READLNMCGA (TEKST);
  SHOWIMAGEMCGA ('CHICKEN.RAW');
  ANIMATECURSORMCGA;
  readln;
  SHOWIMAGEMCGA ('vader.raw');
  ANIMATECURSORMCGA;
  readln;
  SHOWIMAGEMCGA ('emperor.raw');
  ANIMATECURSORMCGA;
  readln;
  CLSMCGA (BLACK);
  SHOWIMAGEMCGABOX ('emperor.raw', 150, 50, 200, 100);
  RECTANGLEMCGA (145, 45, 205, 105);
  ANIMATECURSORMCGA;
  readln;
  textmode (CO80);
end.